@@ -11,10 +11,6 @@ const (
 	HybridOverlayNodeSubnet = HybridOverlayAnnotationBase + "node-subnet"
 	// HybridOverlayDRMAC holds the MAC address of the Distributed Router/gateway
 	HybridOverlayDRMAC = HybridOverlayAnnotationBase + "distributed-router-gateway-mac"
-	// HybridOverlayExternalGW is a namespace annotation that holds the IP address of the external gateway to route default traffic
-	HybridOverlayExternalGw = HybridOverlayAnnotationBase + "external-gw"
-	HybridOverlayVTEP       = HybridOverlayAnnotationBase + "vtep"
-
 	// HybridOverlayVNI is the VNI for VXLAN tunnels between nodes/endpoints
 	HybridOverlayVNI = 4097
 )
